Package: xenLite
Date: 2024-09-19
Title: Simple classes and methods for managing Xenium datasets
Version: 1.6.0
Authors@R: 
    c(person(
        "Vincent", "Carey", role = c("aut", "cre"),
        email = "stvjc@channing.harvard.edu",
        comment = c(ORCID = "0000-0003-4046-0063")
     )
    )
Description: Define a relatively light class for managing Xenium data
        using Bioconductor.  Address use of parquet for coordinates,
        SpatialExperiment for assay and sample data.  Address
        serialization and use of cloud storage.
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.1)
Suggests: knitr, testthat, BiocStyle, yesno, terra,
        SpatialFeatureExperiment, SFEData, tiff
Imports: SpatialExperiment, BiocFileCache, Matrix, S4Vectors,
        SummarizedExperiment, methods, utils, EBImage, shiny,
        HDF5Array, arrow, ggplot2, SingleCellExperiment, TENxIO, dplyr,
        graphics, stats
VignetteBuilder: knitr
biocViews: Infrastructure
RoxygenNote: 7.3.2
URL: https://github.com/vjcitn/xenLite
BugReports: https://github.com/vjcitn/xenLite/issues
Config/pak/sysreqs: cmake libfftw3-dev make libmagick++-dev gsfonts
        libicu-dev libjpeg-dev libpng-dev libtiff-dev libuv1-dev
        libssl-dev libx11-dev zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 13:03:38 UTC
RemoteUrl: https://github.com/bioc/xenLite
RemoteRef: RELEASE_3_23
RemoteSha: bec525eaf63854ec68ba2813129262faf6414420
NeedsCompilation: no
Packaged: 2026-04-30 07:06:03 UTC; root
Author: Vincent Carey [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4046-0063>)
Maintainer: Vincent Carey <stvjc@channing.harvard.edu>
Built: R 4.6.0; ; 2026-04-30 08:34:08 UTC; unix
