# Generated by roxygen2: do not edit by hand

export(XenSPEP)
export(cacheMtif)
export(cacheXenLuad)
export(cacheXenPdmelLite)
export(cacheXenProstLite)
export(clipRect)
export(demoapp)
export(e2sym)
export(getCellBoundaries)
export(getNucleusBoundaries)
export(getTranscripts)
export(ggprepSeg)
export(ingest_xen)
export(loadGeometry)
export(plotXenGgprep)
export(resetParqPaths)
export(restoreZipXenSPEP)
export(viewSeg)
export(viewSegG2)
export(zipXenSPEP)
exportClasses(XenSPEP)
exportMethods("[")
exportMethods(getCellBoundaries)
exportMethods(getNucleusBoundaries)
exportMethods(getTranscripts)
exportMethods(loadGeometry)
exportMethods(show)
import(BiocFileCache)
import(EBImage)
import(HDF5Array)
import(Matrix)
import(SingleCellExperiment)
import(shiny)
importClassesFrom(SpatialExperiment,SpatialExperiment)
importFrom(SummarizedExperiment,"colData<-")
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,ggplot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(methods,"slot<-")
importFrom(methods,as)
importFrom(methods,callNextMethod)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,slot)
importFrom(stats,quantile)
importFrom(utils,data)
importFrom(utils,unzip)
importFrom(utils,zip)
